==> webkit2gtk_2.34.2.orig.tar.xz: webkitgtk-2.34.2/Source/WebKit/UIProcess/Media/MediaUsageManager.h <==
/*
 * Copyright (C) 2020 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <WebCore/MediaUsageInfo.h>
#include <wtf/Forward.h>

namespace WebKit {

class MediaUsageManager {
    WTF_MAKE_FAST_ALLOCATED;
public:
    static std::unique_ptr<MediaUsageManager> create();

    MediaUsageManager() = default;
    virtual ~MediaUsageManager() = default;

    virtual void reset();
    virtual void addMediaSession(WebCore::MediaSessionIdentifier, const String&, const URL&);
    virtual void removeMediaSession(WebCore::MediaSessionIdentifier);
    virtual void updateMediaUsage(WebCore::MediaSessionIdentifier, const WebCore::MediaUsageInfo&);
};

}

==> webkit2gtk_2.48.5.orig.tar.xz: webkitgtk-2.48.5/Source/WebKit/UIProcess/Media/MediaUsageManager.h <==
/*
 * Copyright (C) 2020 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <WebCore/MediaUsageInfo.h>
#include <wtf/Forward.h>
#include <wtf/TZoneMalloc.h>

namespace WebKit {

class MediaUsageManager {
    WTF_MAKE_TZONE_ALLOCATED(MediaUsageManager);
public:
    static std::unique_ptr<MediaUsageManager> create();

    MediaUsageManager() = default;
    virtual ~MediaUsageManager() = default;

    virtual void reset();
    virtual void addMediaSession(WebCore::MediaSessionIdentifier, const String&, const URL&);
    virtual void removeMediaSession(WebCore::MediaSessionIdentifier);
    virtual void updateMediaUsage(WebCore::MediaSessionIdentifier, const WebCore::MediaUsageInfo&);
#if PLATFORM(COCOA) && !HAVE(CGS_FIX_FOR_RADAR_97530095)
    virtual bool isPlayingVideoInViewport() const;
#endif
};

}
